<?php

class Menu_Walker extends Walker_Nav_Menu{

		/**
	 * Traverse elements to create list from elements.
	 *
	 * Display one element if the element doesn't have any children otherwise,
	 * display the element and its children. Will only traverse up to the max
	 * depth and no ignore elements under that depth. It is possible to set the
	 * max depth to include all depths, see walk() method.
	 *
	 * This method shouldn't be called directly, use the walk() method instead.
	 *
	 * @since 2.5.0
	 *
	 * @param object $element Data object
	 * @param array $children_elements List of elements to continue traversing.
	 * @param int $max_depth Max depth to traverse.
	 * @param int $depth Depth of current element.
	 * @param array $args
	 * @param string $output Passed by reference. Used to append additional content.
	 * @return null Null on failure with no changes to parameters.
	 */
	function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ) {

		if ( !$element )
			return;

		$id_field = $this->db_fields['id'];

		//display this element
		if ( is_array( $args[0] ) )
			$args[0]['has_children'] = ! empty( $children_elements[$element->$id_field] );
		
		//Adds the 'parent' class to the current item if it has children		
		if( ! empty( $children_elements[$element->$id_field] ) )
			array_push($element->classes,'dir');
		
		$cb_args = array_merge( array(&$output, $element, $depth), $args);
		
		call_user_func_array(array(&$this, 'start_el'), $cb_args);

		$id = $element->$id_field;

		// descend only when the depth is right and there are childrens for this element
		if ( ($max_depth == 0 || $max_depth > $depth+1 ) && isset( $children_elements[$id]) ) {

			foreach( $children_elements[ $id ] as $child ){

				if ( !isset($newlevel) ) {
					$newlevel = true;
					//start the child delimiter
					$cb_args = array_merge( array(&$output, $depth), $args);
					call_user_func_array(array(&$this, 'start_lvl'), $cb_args);
				}
				$this->display_element( $child, $children_elements, $max_depth, $depth + 1, $args, $output );
			}
			unset( $children_elements[ $id ] );
		}

		if ( isset($newlevel) && $newlevel ){
			//end the child delimiter
			$cb_args = array_merge( array(&$output, $depth), $args);
			call_user_func_array(array(&$this, 'end_lvl'), $cb_args);
		}

		//end this element
		$cb_args = array_merge( array(&$output, $element, $depth), $args);
		call_user_func_array(array(&$this, 'end_el'), $cb_args);
	}
}
$themename = "maXtenta";
function theme_widgets_init() {

if ( function_exists('register_sidebar') )
    register_sidebar(array(
		'name' => 'Right Sidebar',
        'before_widget' => '<div class="sidebar-widg">',
        'after_widget' => '</div>',
        'before_title' => '<h2>',
        'after_title' => '</h2><div class="clear"></div>',
    ));
if ( function_exists('register_sidebar') )
    register_sidebar(array(
		'name' => 'Footer',
        'before_widget' => '<div class="foot-widg">',
        'after_widget' => '</div>',
        'before_title' => '<h2>',
        'after_title' => '</h2><div class="clear"></div>',
    ));
}

add_action( 'widgets_init', 'theme_widgets_init' );	



if ( function_exists( 'add_theme_support' ) ) {
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'imaj', 595, 346, true ); 
	add_image_size('featured-posts', 950, 324, true);

}	
function imaj_image(){

if ( has_post_thumbnail() ) {
	 ?><div class="post-thumbnail"><?php the_post_thumbnail( 'imaj', array('class' => 'entry img post-image-prelaoder') );?><div class="post-thumb-shadow"></div></div><?php
} else {

};

}

if ( function_exists( 'wp_nav_menu' ) ){
	if (function_exists('add_theme_support')) {
		add_theme_support('nav-menus');
		add_action( 'init', 'register_my_menus' );
		function register_my_menus() {
			register_nav_menus(
				array(
					'top-links' => __( 'Top Links' ),
					'main-menu' => __( 'Main Menu' ),
					'footer-links' => __( 'Footer Links' )
				)
			);
		}
	}
}
/* Paginate */
function emm_paginate($args = null) {
	$defaults = array(
		'page' => null, 'pages' => null, 
		'range' => 3, 'gap' => 3, 'anchor' => 1,
		'before' => '<div class="emm-paginate">', 'after' => '</div>',
		'title' => __('Pages:'),
		'nextpage' => __('&raquo;'), 'previouspage' => __('&laquo'),
		'echo' => 1
	);

	$r = wp_parse_args($args, $defaults);
	extract($r, EXTR_SKIP);

	if (!$page && !$pages) {
		global $wp_query;

		$page = get_query_var('paged');
		$page = !empty($page) ? intval($page) : 1;

		$posts_per_page = intval(get_query_var('posts_per_page'));
		$pages = intval(ceil($wp_query->found_posts / $posts_per_page));
	}
	
	$output = "";
	if ($pages > 1) {	
		$output .= "$before<span class='emm-title'>$title</span>";
		$ellipsis = "<span class='emm-gap'>...</span>";

		if ($page > 1 && !empty($previouspage)) {
			$output .= "<a href='" . get_pagenum_link($page - 1) . "' class='emm-prev'>$previouspage</a>";
		}
		
		$min_links = $range * 2 + 1;
		$block_min = min($page - $range, $pages - $min_links);
		$block_high = max($page + $range, $min_links);
		$left_gap = (($block_min - $anchor - $gap) > 0) ? true : false;
		$right_gap = (($block_high + $anchor + $gap) < $pages) ? true : false;

		if ($left_gap && !$right_gap) {
			$output .= sprintf('%s%s%s', 
				emm_paginate_loop(1, $anchor), 
				$ellipsis, 
				emm_paginate_loop($block_min, $pages, $page)
			);
		}
		else if ($left_gap && $right_gap) {
			$output .= sprintf('%s%s%s%s%s', 
				emm_paginate_loop(1, $anchor), 
				$ellipsis, 
				emm_paginate_loop($block_min, $block_high, $page), 
				$ellipsis, 
				emm_paginate_loop(($pages - $anchor + 1), $pages)
			);
		}
		else if ($right_gap && !$left_gap) {
			$output .= sprintf('%s%s%s', 
				emm_paginate_loop(1, $block_high, $page),
				$ellipsis,
				emm_paginate_loop(($pages - $anchor + 1), $pages)
			);
		}
		else {
			$output .= emm_paginate_loop(1, $pages, $page);
		}

		if ($page < $pages && !empty($nextpage)) {
			$output .= "<a href='" . get_pagenum_link($page + 1) . "' class='emm-next'>$nextpage</a>";
		}

		$output .= $after;
	}

	if ($echo) {
		echo $output;
	}

	return $output;
}

function emm_paginate_loop($start, $max, $page = 0) {
	$output = "";
	for ($i = $start; $i <= $max; $i++) {
		$output .= ($page === intval($i)) 
			? "<span class='emm-page emm-current'>$i</span>" 
			: "<a href='" . get_pagenum_link($i) . "' class='emm-page'>$i</a>";
	}
	return $output;
}




add_filter('excerpt_length', 'my_excerpt_length');
function my_excerpt_length($length) {
return 115; }

function new_excerpt_more($more) {
       global $post;
	return ' <a href="'. get_permalink($post->ID) . '"> </a>';
}
add_filter('excerpt_more', 'new_excerpt_more');


/* CallBack functions for menus in case of earlier than 3.0 Wordpress version or if no menu is set yet*/

function toplinks(){ ?>
		<div id="topLinks">
			<ul>		
					<?php wp_list_pages('title_li=')?>

					
			</ul>
			
		</div>
<?php }

function footerlinks(){ ?>
		<div id="footerLinks">
			<ul>
					<li><a href="<?php bloginfo('url'); ?>/">home</a></li>
					<?php wp_list_pages('title_li=') ?>
			</ul>
		</div>
<?php }

function mainmenu(){ ?>
		<div id="topMenu">
			<ul class="sf-menu">
				<?php wp_list_categories('hide_empty=1&exclude=1&title_li='); ?>
			</ul>
		</div>
<?php }

function content($num) {  
		$theContent = get_the_content();  
		$output = preg_replace('/<img[^>]+./','', $theContent);  
		$limit = $num+1;  
		$content = explode(' ', $output, $limit);  
		array_pop($content);  
		$content = implode(" ",$content)."...";  
		echo $content;  
}


function post_is_in_descendant_category( $cats, $_post = null )
{
	foreach ( (array) $cats as $cat ) {
		// get_term_children() accepts integer ID only
		$descendants = get_term_children( (int) $cat, 'category');
		if ( $descendants && in_category( $descendants, $_post ) )
			return true;
	}
	return false;
}

function mytheme_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
   <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
  	

     <div id="comment-<?php comment_ID(); ?>">
	 <div class="cocomment">
      <div class="comment-author vcard">
	  <div class="comment-meta commentmetadata">
	   <?php echo get_avatar($comment,$size='111',$default='http://www.gravatar.com/avatar/61a58ec1c1fba116f8424035089b7c71?s=111&d=&r=G' ); ?>
	 <?php/* edit_comment_link(__('(Edit)'),'  ','') */?></div>
         
      </div>
	  
      <?php if ($comment->comment_approved == '0') : ?>
         <em><?php _e('Your comment is awaiting moderation.') ?></em>
         <br />
      <?php endif; ?>

      <div class="text"><?php comment_text() ?></div>
	  </div>
	  
	  <div class="clear"></div>
	  <div class="metadata-inside reply"><div id="comment-auth"><?php comment_author(); ?></div> <div id="comment-date"><?php comment_date('n-j-Y'); ?></div><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></div>
     </div>
<?php }

add_action('admin_menu', 'cici_theme_page');

function cici_theme_page ()
{
global $themename;

	if ( count($_POST) > 0 && isset($_POST['cici_settings']) )
	{
		$options = array ( 'style','logo_img','logo_alt','logo_txt', 'logo_tagline', 'tagline_width', 'contact_email','ads','ads1', 'advertise_page', 'twitter_link', 'facebook_link', 'about_tit', 'about_txt','image_url1','banner_url1','image_url2','banner_url2','image_url3','banner_url3','image_url4','banner_url4','banner_url5','image_url5', 'banner_url6','image_url6','banner_url7','image_url7','analytics','video','videos','featured', 'slide_cat', 'slide_num', 'slide','ss_color','terms');
		
		foreach ( $options as $opt )
		{
			delete_option ( 'cici_'.$opt, $_POST[$opt] );
			add_option ( 'cici_'.$opt, $_POST[$opt] );	
		}			
		 
	}
	add_theme_page(__($themename)." Panel", __($themename)." Panel", 'edit_themes', basename(__FILE__), 'cici_settings');	
}

function cici_settings ()
{
global $themename, $shortname, $options;
?>
<div class="wrap">
	<h2><?php echo $themename ?> Options Panel</h2>
	
<form method="post" action="">
	<table class="form-table">
		<!-- General settings -->
		<tr>
			<th colspan="2"><strong>General Settings</strong></th>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="logo_img">Logo image (absolute path to image)</label></th>
			<td>
				<input name="logo_img" type="text" id="logo_img" value="<?php echo get_option('cici_logo_img'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="logo_alt">Logo image ALT text</label></th>
			<td>
				<input name="logo_alt" type="text" id="logo_alt" value="<?php echo get_option('cici_logo_alt'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="contact_email">Email Address for Contact Form</label></th>
			<td>
				<input name="contact_email" type="text" id="contact_email" value="<?php echo get_option('cici_contact_email'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="twitter_link">Twitter ID</label></th>
			<td>
				<input name="twitter_link" type="text" id="twitter_link" value="<?php echo get_option('cici_twitter_link'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="facebook_link">Facebook link</label></th>
			<td>
				<input name="facebook_link" type="text" id="facebook_link" value="<?php echo get_option('cici_facebook_link'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="terms">Terms of use link</label></th>
			<td>
				<input name="terms" type="text" id="terms" value="<?php echo get_option('cici_terms'); ?>" class="regular-text" />
			</td>
		</tr>
		<!-- Sidebar ABout Box-->
		<tr>
			<th colspan="2"><strong>Text Widget</strong></th>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="about_tit">Title</label></th>
			<td>
				<input name="about_tit" type="text" id="about_tit" value="<?php echo get_option('cici_about_tit'); ?>" class="regular-text" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="about_txt">Text</label></th>
			<td>
				<textarea cols="60" rows="5" name="about_txt" type="text" id="about_txt" class="regular-text" /><?php echo get_option('cici_about_txt'); ?></textarea>
			</td>
		</tr>
		<tr>
			<th colspan="2"><strong>Ads Sidebar 250x200 Box Settings</strong></th>
		</tr>
		<tr>
			<th><label for="ads">Ads Section Enabled:</label></th>
			<td>
				<select name="ads1" id="ads1">
					<option value="no" <?php if(get_option('cici_ads1') == 'no'){?>selected="selected"<?php }?>>No</option>
					<option value="yes" <?php if(get_option('cici_ads1') == 'yes'){?>selected="selected"<?php }?>>Yes</option>
				</select> 
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="image_url5">Image URL 1</label></th>
			<td>
				<input name="image_url5" type="text" id="image_url5" value="<?php echo get_option('cici_image_url5'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url5">Banner URL 1</label></th>
			<td>
				<input name="banner_url5" type="text" id="banner_url5" value="<?php echo get_option('cici_banner_url5'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="image_url6">Image URL 2</label></th>
			<td>
				<input name="image_url6" type="text" id="image_url6" value="<?php echo get_option('cici_image_url6'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url6">Banner URL 2</label></th>
			<td>
				<input name="banner_url6" type="text" id="banner_url6" value="<?php echo get_option('cici_banner_url6'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="image_url7">Image URL 3</label></th>
			<td>
				<input name="image_url7" type="text" id="image_url7" value="<?php echo get_option('cici_image_url7'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url7">Banner URL 3</label></th>
			<td>
				<input name="banner_url7" type="text" id="banner_url7" value="<?php echo get_option('cici_banner_url7'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr>
			<th colspan="2"><strong>Ads Sidebar 125x125 Box Settings</strong></th>
		</tr>
		<tr>
			<th><label for="ads">Ads Section Enabled:</label></th>
			<td>
				<select name="ads" id="ads">
					<option value="no" <?php if(get_option('cici_ads') == 'no'){?>selected="selected"<?php }?>>No</option>
					<option value="yes" <?php if(get_option('cici_ads') == 'yes'){?>selected="selected"<?php }?>>Yes</option>
				</select> 
			</td>
		</tr>

		<tr valign="top">
			<th scope="row"><label for="image_url1">Image URL 1</label></th>
			<td>
				<input name="image_url1" type="text" id="image_url1" value="<?php echo get_option('cici_image_url1'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url1">Banner URL 1</label></th>
			<td>
				<input name="banner_url1" type="text" id="banner_url1" value="<?php echo get_option('cici_banner_url1'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="image_url2">Image URL 2</label></th>
			<td>
				<input name="image_url2" type="text" id="image_url2" value="<?php echo get_option('cici_image_url2'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url2">Banner URL 2</label></th>
			<td>
				<input name="banner_url2" type="text" id="banner_url2" value="<?php echo get_option('cici_banner_url2'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="image_url3">Image URL 3</label></th>
			<td>
				<input name="image_url3" type="text" id="image_url3" value="<?php echo get_option('cici_image_url3'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url3">Banner URL 3</label></th>
			<td>
				<input name="banner_url3" type="text" id="banner_url3" value="<?php echo get_option('cici_banner_url3'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="image_url4">Image URL 4</label></th>
			<td>
				<input name="image_url4" type="text" id="image_url4" value="<?php echo get_option('cici_image_url4'); ?>" class="regular-text" />
			</td>
		</tr>
		
		<tr valign="top">
			<th scope="row"><label for="banner_url4">Banner URL 4</label></th>
			<td>
				<input name="banner_url4" type="text" id="banner_url4" value="<?php echo get_option('cici_banner_url4'); ?>" class="regular-text" />
			</td>
		</tr>
		<!-- Google Analytics -->
		<tr>
			<th><label for="ads">Google Analytics code:</label></th>
			<td>
				<textarea name="analytics" id="analytics" rows="7" cols="70" style="font-size:11px;"><?php echo stripslashes(get_option('cici_analytics')); ?></textarea>
			</td>
		</tr>
        <!-- Featured Posts -->
		<tr>
			<th colspan="2"><strong>Fetaured Posts</strong></th>
		</tr>
       <tr>
			<th><label for="slide">Featured Slider Section Enabled:</label></th>
			<td>
				<select name="slide" id="slide">
					<option value="no" <?php if(get_option('cici_slide') == 'no'){?>selected="selected"<?php }?>>No</option>
					<option value="yes" <?php if(get_option('cici_slide') == 'yes'){?>selected="selected"<?php }?>>Yes</option>
				</select> 
			</td>
		</tr>
        <tr valign="top">
			<th scope="row"><label for="slide_cat">Select the category</label></th>
            <td>
            <select name="slide_cat" id="slide_cat" style="width:250px;">
            <?php
				$categories = get_categories('hide_empty=0&orderby=name');				
				foreach ($categories as $category_list ) { ?>
                
				<option value="<?php echo $category_list->cat_name; ?>" <?php if(get_option('cici_slide_cat') == $category_list->cat_name){?>selected="selected"<?php }?>><?php echo $category_list->cat_name; ?></option>			
					    
			<?php	}
			?>
            </select>
            </td>
		</tr>
               
        <tr valign="top">
			<th scope="row"><label for="slide_num">How many Slides you want?</label></th>
			<td>
				<select name="slide_num" id="slide_num">
					<option value="1" <?php if(get_option('cici_slide_num') == '1'){?>selected="selected"<?php }?>>1</option>
					<option value="2" <?php if(get_option('cici_slide_num') == '2'){?>selected="selected"<?php }?>>2</option>
					<option value="3" <?php if(get_option('cici_slide_num') == '3'){?>selected="selected"<?php }?>>3</option>
					<option value="4" <?php if(get_option('cici_slide_num') == '4'){?>selected="selected"<?php }?>>4</option>
					<option value="5" <?php if(get_option('cici_slide_num') == '5'){?>selected="selected"<?php }?>>5</option>
					<option value="6" <?php if(get_option('cici_slide_num') == '6'){?>selected="selected"<?php }?>>6</option>
					<option value="7" <?php if(get_option('cici_slide_num') == '7'){?>selected="selected"<?php }?>>7</option>
					<option value="8" <?php if(get_option('cici_slide_num') == '8'){?>selected="selected"<?php }?>>8</option>
					<option value="9" <?php if(get_option('cici_slide_num') == '9'){?>selected="selected"<?php }?>>9</option>
					<option value="10" <?php if(get_option('cici_slide_num') == '10'){?>selected="selected"<?php }?>>10</option>
				</select>
			</td>
		</tr>
		
		
	</table>
	<p class="submit">
		<input type="submit" name="Submit" class="button-primary" value="Save Changes" />
		<input type="hidden" name="cici_settings" value="save" style="display:none;" />
	</p>
</form>

</div>
<?php }
function get_first_image() {
global $post, $posts;
$first_img = '';
ob_start();
ob_end_clean();
$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
$first_img = $matches [1] [0];
if(empty($first_img)){ //Defines a default image
$first_img = "/images/default.jpg";
}
return $first_img;
} ?>
<?php
add_action( 'wp_print_scripts', 'my_deregister_javascript', 100 );
function my_deregister_javascript() {
if ( is_home() ) {
wp_deregister_script( 'contact-form-7' );
}
}

function dimox_breadcrumbs() {
 
  $delimiter = '&raquo;';
  $home = 'Home'; // text for the 'Home' link
  $before = '<span class="current">'; // tag before the current crumb
  $after = '</span>'; // tag after the current crumb
 
  if ( !is_home() && !is_front_page() || is_paged() ) {
 
    echo '<div id="crumbs">';
 
    global $post;
    $homeLink = get_bloginfo('url');
    echo '<a href="' . $homeLink . '">' . $home . '</a> ' . $delimiter . ' ';
 
    if ( is_category() ) {
      global $wp_query;
      $cat_obj = $wp_query->get_queried_object();
      $thisCat = $cat_obj->term_id;
      $thisCat = get_category($thisCat);
      $parentCat = get_category($thisCat->parent);
      if ($thisCat->parent != 0) echo(get_category_parents($parentCat, TRUE, ' ' . $delimiter . ' '));
      echo $before . 'Archive by category "' . single_cat_title('', false) . '"' . $after;
 
    } elseif ( is_day() ) {
      echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
      echo '<a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
      echo $before . get_the_time('d') . $after;
 
    } elseif ( is_month() ) {
      echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
      echo $before . get_the_time('F') . $after;
 
    } elseif ( is_year() ) {
      echo $before . get_the_time('Y') . $after;
 
    } elseif ( is_single() && !is_attachment() ) {
      if ( get_post_type() != 'post' ) {
        $post_type = get_post_type_object(get_post_type());
        $slug = $post_type->rewrite;
        echo '<a href="' . $homeLink . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a> ' . $delimiter . ' ';
        echo $before . get_the_title() . $after;
      } else {
        $cat = get_the_category(); $cat = $cat[0];
        echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
        echo $before . get_the_title() . $after;
      }
 
    } elseif ( !is_single() && !is_page() && get_post_type() != 'post' ) {
      $post_type = get_post_type_object(get_post_type());
      echo $before . $post_type->labels->singular_name . $after;
 
    } elseif ( is_attachment() ) {
      $parent = get_post($post->post_parent);
      $cat = get_the_category($parent->ID); $cat = $cat[0];
      echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
      echo '<a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a> ' . $delimiter . ' ';
      echo $before . get_the_title() . $after;
 
    } elseif ( is_page() && !$post->post_parent ) {
      echo $before . get_the_title() . $after;
 
    } elseif ( is_page() && $post->post_parent ) {
      $parent_id  = $post->post_parent;
      $breadcrumbs = array();
      while ($parent_id) {
        $page = get_page($parent_id);
        $breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
        $parent_id  = $page->post_parent;
      }
      $breadcrumbs = array_reverse($breadcrumbs);
      foreach ($breadcrumbs as $crumb) echo $crumb . ' ' . $delimiter . ' ';
      echo $before . get_the_title() . $after;
 
    } elseif ( is_search() ) {
      echo $before . 'Search results for "' . get_search_query() . '"' . $after;
 
    } elseif ( is_tag() ) {
      echo $before . 'Posts tagged "' . single_tag_title('', false) . '"' . $after;
 
    } elseif ( is_author() ) {
       global $author;
      $userdata = get_userdata($author);
      echo $before . 'Articles posted by ' . $userdata->display_name . $after;
 
    } elseif ( is_404() ) {
      echo $before . 'Error 404' . $after;
    }
 
    if ( get_query_var('paged') ) {
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
      echo __('Page') . ' ' . get_query_var('paged');
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
    }
 
    echo '</div>';
 
  }
} // end dimox_breadcrumbs()
?>